@@ -4,7 +4,7 @@ from expressmoney.api import *
 from expressmoney.viewflow import result
 
 
-SERVICE = 'prfiles'
+SERVICE = 'profiles'
 APP = 'credit_scoring'
 
 
