@@ -15,7 +15,7 @@ class ProfileScoringReadContract(Contract):
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
     score = serializers.DecimalField(max_digits=3, decimal_places=2)
-    credit_dataset = serializers.IntegerField(min_value=1)
+    sample = serializers.IntegerField(min_value=1)
 
 
 class ProfileScoringResponseContract(ProfileScoringReadContract):
